==> typo3-src_4.0.4+debian.orig.tar.gz: typo3_src-4.0.4/typo3/sysext/beuser/ext_emconf.php <==
<?php

########################################################################
# Extension Manager/Repository config file for ext: "beuser"
# 
# Auto generated 17-11-2004 17:47
# 
# Manual updates:
# Only the data in the array - anything else is removed by next write
########################################################################

$EM_CONF[$_EXTKEY] = Array (
	'title' => 'Tools>User Admin',
	'description' => 'Backend user administration and overview. Allows you to compare the settings of users and verify their permissions.',
	'category' => 'module',
	'shy' => 1,
	'dependencies' => '',
	'conflicts' => '',
	'priority' => '',
	'loadOrder' => '',
	'TYPO3_version' => '3.7.0-',
	'PHP_version' => '0.0.1-0.0.1',
	'module' => 'mod',
	'state' => 'stable',
	'internal' => 0,
	'uploadfolder' => 0,
	'createDirs' => '',
	'modify_tables' => '',
	'clearCacheOnLoad' => 0,
	'lockType' => '',
	'author' => 'Kasper Skrhj',
	'author_email' => 'kasperYYYY@typo3.com',
	'author_company' => 'Curby Soft Multimedia',
	'CGLcompliance' => '',
	'CGLcompliance_note' => '',
	'private' => 0,
	'download_password' => '',
	'version' => '0.1.3',	// Don't modify this! Managed automatically during upload to repository.
	'_md5_values_when_last_written' => 'a:17:{s:12:"ext_icon.gif";s:4:"2804";s:14:"ext_tables.php";s:4:"c05c";s:14:"mod/beuser.gif";s:4:"2804";s:13:"mod/clear.gif";s:4:"cc11";s:12:"mod/conf.php";s:4:"8ab5";s:13:"mod/index.php";s:4:"4f6a";s:21:"mod/locallang_mod.xml";s:4:"3450";s:15:"mod/CVS/Entries";s:4:"dc4c";s:18:"mod/CVS/Repository";s:4:"fdea";s:12:"mod/CVS/Root";s:4:"0ea2";s:12:"doc/TODO.txt";s:4:"93f7";s:15:"doc/CVS/Entries";s:4:"4f35";s:18:"doc/CVS/Repository";s:4:"7ada";s:12:"doc/CVS/Root";s:4:"0ea2";s:11:"CVS/Entries";s:4:"becc";s:14:"CVS/Repository";s:4:"bfc3";s:8:"CVS/Root";s:4:"0ea2";}',
);

?>

==> typo3-src_4.1.2+debian.orig.tar.gz: typo3_src-4.1.2/typo3/sysext/beuser/ext_emconf.php <==
<?php

########################################################################
# Extension Manager/Repository config file for ext: "beuser"
# 
# Auto generated 17-11-2004 17:47
# 
# Manual updates:
# Only the data in the array - anything else is removed by next write
########################################################################

$EM_CONF[$_EXTKEY] = Array (
	'title' => 'Tools>User Admin',
	'description' => 'Backend user administration and overview. Allows you to compare the settings of users and verify their permissions and see who is online.',
	'category' => 'module',
	'shy' => 1,
	'dependencies' => '',
	'conflicts' => '',
	'priority' => '',
	'loadOrder' => '',
	'TYPO3_version' => '3.7.0-',
	'PHP_version' => '0.0.1-0.0.1',
	'module' => '',
	'state' => 'stable',
	'internal' => 0,
	'uploadfolder' => 0,
	'createDirs' => '',
	'modify_tables' => '',
	'clearCacheOnLoad' => 0,
	'lockType' => '',
	'author' => 'Kasper Skrhj',
	'author_email' => 'kasperYYYY@typo3.com',
	'author_company' => 'Curby Soft Multimedia',
	'CGLcompliance' => '',
	'CGLcompliance_note' => '',
	'private' => 0,
	'download_password' => '',
	'version' => '0.2.0',	// Don't modify this! Managed automatically during upload to repository.
	'_md5_values_when_last_written' => 'a:17:{s:12:"ext_icon.gif";s:4:"2804";s:14:"ext_tables.php";s:4:"c05c";s:14:"mod/beuser.gif";s:4:"2804";s:13:"mod/clear.gif";s:4:"cc11";s:12:"mod/conf.php";s:4:"8ab5";s:13:"mod/index.php";s:4:"4f6a";s:21:"mod/locallang_mod.xml";s:4:"3450";s:15:"mod/CVS/Entries";s:4:"dc4c";s:18:"mod/CVS/Repository";s:4:"fdea";s:12:"mod/CVS/Root";s:4:"0ea2";s:12:"doc/TODO.txt";s:4:"93f7";s:15:"doc/CVS/Entries";s:4:"4f35";s:18:"doc/CVS/Repository";s:4:"7ada";s:12:"doc/CVS/Root";s:4:"0ea2";s:11:"CVS/Entries";s:4:"becc";s:14:"CVS/Repository";s:4:"bfc3";s:8:"CVS/Root";s:4:"0ea2";}',
);

?>
